import os

VER_ADAIVU = os.path.realpath(os.path.join(os.path.dirname(__file__), '..'))

THARAVU_ADAIVU = f'{VER_ADAIVU}/tharavu'

ADAIYALAMITTA_ARI_PATH = f'{THARAVU_ADAIVU}/adaiyalamitta-ari.txt'
ARI_PATH               = f'{THARAVU_ADAIVU}/ari.txt'
ARI_UNI_PATH           = f'{THARAVU_ADAIVU}/ari-uni.txt'
UYIRMEI_MAP_PATH       = f'{THARAVU_ADAIVU}/uyir-mei.csv'
